==> cook_2.5.orig.tar.gz: cook-2.5.orig/test/00/t0084a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1995, 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the double colon functionality
#
work=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the double colon functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT test of the double colon functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

#
# test the double colon functionality
#
cat > Howto.cook << 'fubar'
test:: ::
{
	touch test;
}
fubar
if test $? -ne 0 ; then no_result; fi

$bin/cook -nl > LOG 2>&1
if test $? -ne 0 ; then car LOG; fail; fi

cat > Howto.cook << 'fubar'
test: bar
{
	touch test;
}

%0bar: : %0baz
{
	cp [need] [target];
}
fubar
if test $? -ne 0 ; then no_result; fi
cat > test.ok << 'fubar'
cook: baz: don't know how
cook: Howto.cook: 6: "bar" not derived due to errors deriving "baz"
cook: Howto.cook: 1: "test" not derived due to errors deriving "bar"
fubar
if test $? -ne 0 ; then no_result; fi

echo hello > bar
if test $? -ne 0 ; then no_result; fi

$bin/cook -nl > test.out 2>&1
if test $? -ne 1 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

==> cook-2.16.tar.gz: cook-2.16/test/00/t0084a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1995, 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the double colon functionality
#
work=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the double colon functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT test of the double colon functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

#
# test the double colon functionality
#
cat > howto.cook << 'fubar'
test:: ::
{
	touch test;
}
fubar
if test $? -ne 0 ; then no_result; fi

$bin/cook -nl > LOG 2>&1
if test $? -ne 0 ; then car LOG; fail; fi

cat > howto.cook << 'fubar'
test: bar
{
	touch test;
}

%0bar: : %0baz
{
	cp [need] [target];
}
fubar
if test $? -ne 0 ; then no_result; fi
cat > test.ok << 'fubar'
cook: baz: don't know how
cook: howto.cook: 6: "bar" not derived due to errors deriving "baz"
cook: howto.cook: 1: "test" not derived due to errors deriving "bar"
fubar
if test $? -ne 0 ; then no_result; fi

echo hello > bar
if test $? -ne 0 ; then no_result; fi

$bin/cook -nl > test.out 2>&1
if test $? -ne 1 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
